@echo off

:: Windows build script for MuseScore, v0.9.6+, including the 
:: nightlies, written by Peter Schepers. This script goes into 
:: the MuseScore source folder where the "makefile.mingw" file 
:: resides. Execute it to build MuseScore.
::
:: You may need to execute this script with admin rights to build!
:: Under Win7/Vista, run it with "Run as administrator".
::
:: Note the variable names in this script are chosen so that
:: they hopefully won't conflict or overwrite any other system or
:: user variable that already exists.

:: Default paths for compilation dependancies.
:: Change these to the correct installation paths
set XXCMAKE=c:\Program Files\CMake 2.8\bin
set XXMINGW=e:\qtsdk\mingw\bin
set XXQP=e:\qtsdk\desktop\qt\4.7.3\mingw\bin

:: When this script is executed using "Run as administrator" under
:: Windows 7 or Vista, the path is switched to c:\windows\system32.
:: This doesn't happen under Windows XP. So, if the main Makefile
:: is not seen when the script starts, it can't be running from the
:: proper path and I assume we are under Win7.
if exist Makefile.mingw goto STARTOK

:: Win7/Vista fix
:: These commands switch the path back to where the script was executed.
:: CD back to proper drive
%~d0
:: and path
cd "%~p0"

:STARTOK

:: Assume the source path is where this script is
set XXSOURCE=%cd%

:: Clear out the dependancy error flag
set XXERROR=

echo.
echo **** MuseScore Build Script for Windows ****
echo  Last Updated: June 6, 2011
echo   Source path: %XXSOURCE%

echo.
echo Checking that the CMAKE, MinGW and Qt paths are correct...

:: Check and add required compilation tool paths to the SYSTEM path,
:: for this session only. This gets around the need to add any
:: paths manually to the system PATH variable and allows you to
:: move to other source folders and compile them without any
:: changes to this script.
::
:: This method is also handy because it keeps all the DLL
:: libraries out of the path so that if some DLL is missing
:: after compilation, you will know when MuseScore is launched.

:: Check CMAKE path
if not exist "%XXCMAKE%" goto NOCMAKE

:: Add CMAKE path to SYSTEM PATH variable
set path=%path%;%XXCMAKE%
goto MINGW

:NOCMAKE

echo.
echo **** ERROR **** The CMAKE install was not found at path
echo    %XXCMAKE%
echo.
set XXERROR=1

:MINGW

::Check MINGW path

if not exist %XXMINGW%\NUL goto NOMINGW

:: Add MINGW path to SYSTEM PATH variable
set path=%path%;%XXMINGW%
goto QT

:NOMINGW

echo **** ERROR **** The MINGW install (part of Qt SDK) not found at path
echo    %XXMINGW%
echo.
set XXERROR=1

:QT

::Check Qt path

if not exist %XXQP%\NUL goto NOQT

:: Add Qt path to SYSTEM PATH variable
set path=%path%;%XXQP%

if "%XXERROR%Z"=="Z" goto PATHSOK

:NOQT

echo **** ERROR **** The Qt SDK install not found at path
echo    %XXQP%
echo.

echo Some dependancies were not found at the default paths.
echo Edit this script, correct the dependancy paths, and try again.
echo.
goto QUIT1

:PATHSOK

echo All the paths appear Ok.
echo.

:: Add present compilation path to SYSTEM PATH variable
set path=%path%;%XXSOURCE%

:: Check for Tortoise or SubVersion executables
echo Checking which SVN program exists (Tortoise or SubVersion)...
subwcrev.exe %XXSOURCE%>NUL
if %errorlevel% neq 0 goto SVN1

:: Get version of last update using TortoiseSVN
set XXVER=
echo Found TortoiseSVN.
echo.
echo Obtaining build revision for "%XXSOURCE%"
for /f "tokens=1-4 delims= " %%a in ('subwcrev.exe %XXSOURCE% ^| find /i "Updated to revision"') do set XXVER=%%d

:: If the revision is empty, fail
if "%XXVER%Z"=="Z" goto SVNFAIL

:SVNOK

:: Otherwise assume it's OK
echo OK, got the number. The build revision is %XXVER%.
echo.
goto ASKQ

:SVN1

echo.
echo TortoiseSVN not found. Looking for SubVersion...

svnversion.exe -n>NUL
if %errorlevel% neq 0 goto SVNFAIL

echo Found Collab SubVersion.
echo.
echo Obtaining build revision for "%XXSOURCE%"

:: Now try the SVNVersion way
for /f "tokens=1 delims=M" %%a in ('svnversion.exe -n') do set XXREV=%%a

:: If the revision is not empty, were OK
if not "%XXVER%Z"=="Z" goto SVNOK

:SVNFAIL

echo.
echo Oops, failed again!

:ASKQ

:: Delete temp path variables, they are not needed anymore
set XXMINGW=
set XXCMAKE=
set XXQP=
set XXSOURCE=

:: Set temp variables
set XXQ1=n
set XXQ2=n
set XXQ3=n
set XXQ4=n

:: Massage build version.
:: If it doesn't convert to a number, throw it away.
set /a XXVER=%XXVER%
if %XXVER%==0 set XXVER=

:: Question time
:: If I didn't get the build version previously using SVN, ask for present MS build revision
if "%XXVER%Z"=="Z" set /p XXVER=Enter the present revision of this MuseScore build (####): 

:: Ask about cleaning out the previous compile/install
set /p XXQ1=Delete the previous WIN32BUILD and WIN32INSTALL folders first [y/N]? 

:: Ask about compiling the MS Win32 executable
set /p XXQ2=Compile the MuseScore WIN32 executable [y/N]? 

:: Ask about compiling the MS installation folder
set /p XXQ3=Create the complete MuseScore installation folder [y/N]? 

:: Ask about compiling the MS installable PACKAGE EXE
set /p XXQ4=Create the MuseScore installable PACKAGE (requires NSIS) [y/N]? 

:: Update revision
echo.
echo Setting build revision in MuseScore source code to %XXVER%.
echo %XXVER% > mscore\mscore\revision.h
echo Done.

:DEL

:: If deleting the previous build folders
if "%XXQ1%"=="y" goto B1
if "%XXQ1%"=="Y" goto B1
goto B11

:B1

echo.
echo Deleting previous MuseScore WIN32BUILD and WIN32INSTALL folders...
rmdir /S /Q win32build win32install>NUL

echo Done.

:B11

echo.
echo Skipping the deletion of previous build folders.

:: If building the MSCORE.EXE
if "%XXQ2%"=="y" goto B2
if "%XXQ2%"=="Y" goto B2
goto B22

:B2

:: Create the Win32 executable
echo.
echo Compiling the MuseScore executable...
echo.

mingw32-make -f Makefile.mingw win32
if not errorlevel==0 goto ERROR

:B22

echo.
echo Skipping the Win32 MSCORE.EXE build.

:: If not building the installation folder goto the next build
if "%XXQ3%"=="y" goto B3
if "%XXQ3%"=="Y" goto B3
goto B33

:B3

:: Create the INSTALL folder
echo.
echo Creating MuseScore installation folder...
echo.

mingw32-make -f Makefile.mingw install
if not errorlevel==0 goto ERROR

:B33

echo.
echo Skipping the installation folder.

:: If not building the installation package were done
if "%XXQ4%"=="y" goto B4
if "%XXQ4%"=="Y" goto B4
goto B44

:B4

:: Create the installable PACKAGE
echo.
echo Compiling MuseScore to the installable package...
echo.

mingw32-make -f Makefile.mingw package
if not errorlevel==0 goto ERROR

:B44

echo.
echo Skipping the package build.

:DONE

echo.
echo Everything requested has been completed.
echo.
echo If you compiled the MS executable, it is in the WIN32BUILD\MSCORE folder.
echo If you built the installation folder, MS is in the WIN32INSTALL\BIN folder.
echo If you built the installable package, it is in the WIN32BUILD folder.
echo.
goto QUIT1

:ERROR

echo.
echo An error occurred during compilation which should be shown above.
echo Please correct it before compiling again!
echo.

:QUIT1

echo Press any key to exit this script.

pause>NUL

:QUIT

set XXVER=
set XXQ1=
set XXQ2=
set XXQ3=
set XXQ4=
